==> exo.platform.packaging.source-3.0.8.zip: social-project-1.1.8/component/common/src/main/java/org/exoplatform/social/common/ResourceBundleUtil.java <==
/*
 * Copyright (C) 2003-2010 eXo Platform SAS.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see<http://www.gnu.org/licenses/>.
 */
package org.exoplatform.social.common;

import java.util.List;

/**
 * ResourceBunleUtil
 *
 * @author    <a href="http://hoatle.net">hoatle (hoatlevan at gmail dot com)</a>
 * @since     Aug 31, 2010
 * @copyright eXo SAS
 */
public class ResourceBundleUtil {

  /**
   * Replace convention arguments of pattern {index} with messageArguments[index].
   * @param message
   * @param messageArguments
   * @return expected message with replaced arguments
   */
  public static String replaceArguments(String message, String[] messageArguments) {
    for (int i = 0; i < messageArguments.length; i++) {
      message = message.replace("{" + i + "}", messageArguments[i]);
    }
    return message;
  }
  
  /**
   * Replace convention arguments of pattern {index} with messageArguments[index].
   * @param message
   * @param messageArguments
   * @return expected message with replaced arguments
   */
  public static String replaceArguments(String message, List<String> messageArguments) {
    for (int i = 0; i < messageArguments.size(); i++) {
      message = message.replace("{" + i + "}", messageArguments.get(i));
    }
    return message;
  }
}

==> exo.platform.packaging.source-3.0.10.zip: social-project-1.1.10/component/common/src/main/java/org/exoplatform/social/common/ResourceBundleUtil.java <==
/*
 * Copyright (C) 2003-2010 eXo Platform SAS.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see<http://www.gnu.org/licenses/>.
 */
package org.exoplatform.social.common;

import java.text.MessageFormat;
import java.util.List;

/**
 * ResourceBunleUtil
 *
 * @author    <a href="http://hoatle.net">hoatle (hoatlevan at gmail dot com)</a>
 * @since     Aug 31, 2010
 * @copyright eXo SAS
 */
public class ResourceBundleUtil {

  private static final ThreadLocal<MessageFormat> messageFormatRef = new ThreadLocal<MessageFormat>() {
    @Override
    protected MessageFormat initialValue() {
      return new MessageFormat("");
    }
  };

  private static final String[] EMPTY_MESSAGE_ARGUMENTS = new String[]{};
  
  /**
   * Replace convention arguments of pattern {index} with messageArguments[index].
   * @param message
   * @param messageArguments
   * @return expected message with replaced arguments
   */
  public static String replaceArguments(String message, String[] messageArguments) {
    if (messageArguments == null) {
      messageArguments = EMPTY_MESSAGE_ARGUMENTS;
    }
    
    final MessageFormat messageFormat = messageFormatRef.get();
    messageFormat.applyPattern(message);
    return messageFormat.format(messageArguments);
  }
  
  /**
   * Replace convention arguments of pattern {index} with messageArguments[index].
   * @param message
   * @param messageArguments
   * @return expected message with replaced arguments
   */
  public static String replaceArgs(String message, List<String> messageArguments) {
    String[] messageArgs =  (String[])messageArguments.toArray(new String[0]);
    return replaceArguments(message, messageArgs);
  }
  
  /**
   * Replace convention arguments of pattern {index} with messageArguments[index].
   * @param message
   * @param messageArguments
   * @return expected message with replaced arguments
   */
  public static String replaceArguments(String message, List<String> messageArguments) {
    for (int i = 0; i < messageArguments.size(); i++) {
      message = message.replace("{" + i + "}", messageArguments.get(i));
    }
    return message;
  }
}
